@@ -26,9 +26,9 @@ class DetectController:
             raise Exception(res.text)
 
     @verify_credentials
-    def describe_activity(self, days=7):
+    def describe_activity(self, start: str, finish: str):
         """ Get report for an Account """
-        params = dict(days=days)
+        params = dict(start=start, finish=finish)
         res = requests.get(f'{self.account.hq}/detect/activity', headers=self.account.headers, params=params)
         if res.status_code == 200:
             return res.json()
@@ -85,3 +85,20 @@ class DetectController:
         if res.status_code == 200:
             return res.text
         raise Exception(res.text)
+
+    @verify_credentials
+    def search(self, identifier: str):
+        """ Search the NVD for a keyword """
+        params = dict(identifier=identifier)
+        res = requests.get(f'{self.account.hq}/detect/search', headers=self.account.headers, params=params)
+        if res.status_code == 200:
+            return res.json()
+        raise Exception(res.text)
+
+    @verify_credentials
+    def list_rules(self):
+        """ Return all Verified Security Rules """
+        res = requests.get(f'{self.account.hq}/detect/rules', headers=self.account.headers)
+        if res.status_code == 200:
+            return res.json()
+        raise Exception(res.text)
