@@ -33,18 +33,21 @@ class Permission(Enum):
         return Permission.UNKNOWN
 
 @unique
-class Lookup(Enum):
+class ExitCode(Enum):
+    OTHER = -1
     ERROR = 1
-    PASSED = 100
-    FAILED = 101
+    MALFORMED_VST = 2
+    PROCESS_KILLED = 9
+    PROTECTED = 100
+    UNPROTECTED = 101
     TIMEOUT = 102
     CLEANUP_ERROR = 103
     NOT_RELEVANT = 104
-    QUARANTINED = 105
-    INCOMPATIBLE = 126
-    QUARANTINED_VST = 127
+    QUARANTINED_1 = 105
+    INCOMPATIBLE_HOST = 126
+    QUARANTINED_2 = 127
     UNEXPECTED = 256
 
     @classmethod
     def _missing_(cls, value):
-        return Lookup.UNEXPECTED
+        return ExitCode.OTHER
